# eric7.QScintilla.KeySequenceTranslator

Module implementing functions to map QScintilla keyboard commands to QKeySequence standard keys.

### Global Attributes

Scintilla2QKeySequence
__all__

### Classes

None

### Functions

s2qTranslate | Function to translate a QScintilla command to a QKeySequence.

## s2qTranslate

s2qTranslate(scintillaCommand)

Function to translate a QScintilla command to a QKeySequence.

scintillaCommand (int)
  QScintilla command

Return:
  Qt key sequence

Return Type:
  QKeySequence.StandardKey

Up